#!/usr/bin/env python
from setuptools import setup

setup(
    name="django-sluggee",
    version="0.1",
    description="Russian slugifier for Django",
    long_description="Django's 'slugify' wrapper to slugify russian easily.",
    keywords="django, slug",
    author="Dima Kurguzov",
    author_email="koorgoo@gmail.com",
    url="https://github.com/koorgoo/djangl-sluggee/",
    license="MIT",
    packages=["sluggee"],
    zip_safe=False,
    install_requires=[],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: Django",
        "Environment :: Web Environment",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3"
    ],
)



# -*- coding: utf-8 -*-
from functools import wraps
from django.utils.text import slugify as _slugify
from .translit import RU_EN
from .six import u


def slugify(value):
    new_value = u('')
    for c in u(value).lower():
        new_value += RU_EN.get(c, c)
    return _slugify(new_value)
